FileDownloader class

File download functionality for RangeRequestClient

Constructors

FileDownloader([RangeRequestClient? client])
FileDownloader.fromConfig(RangeRequestConfig config)
Create a FileDownloader with a new RangeRequestClient using the provided config
factory

Properties

client RangeRequestClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupTempFiles(String directory, {String? tempFileExtension, Duration? olderThan}) Future<int>
Clean up all temporary files in the specified directory
downloadToFile(Uri url, String outputDir, {String? outputFileName, bool resume = true, ChecksumType checksumType = ChecksumType.none, FileConflictStrategy conflictStrategy = FileConflictStrategy.overwrite, CancelToken? cancelToken, void onProgress(int bytes, int total, DownloadStatus status)?}) Future<DownloadResult>
Downloads content directly to a file with optional progress callback Supports resuming partial downloads if the file already exists Calculates checksum based on checksumType parameter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited