CancelToken class
Token for cancelling download operations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
Whether the operation has been cancelled
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void - Cancel the operation
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerClient(
Client client) → void - Register a client for cancellation (used internally by fetch operations)
-
throwIfCancelled(
) → void - Check if cancelled and throw exception if true
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterClient(
) → void - Unregister the client
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited